# Visuomotor Serial Targeting Task (VSTT)

[![PyPI](https://img.shields.io/pypi/v/vstt.svg)](https://pypi.org/project/vstt)
[![Docs](https://readthedocs.org/projects/vstt/badge/?version=main)](https://vstt.readthedocs.io)
[![CI](https://github.com/ssciwr/vstt/actions/workflows/ci.yml/badge.svg)](https://github.com/ssciwr/vstt/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/ssciwr/vstt/branch/main/graph/badge.svg?token=sjsAdTyLH1)](https://codecov.io/gh/ssciwr/vstt)
[![Sonar](https://sonarcloud.io/api/project_badges/measure?project=ssciwr_vstt&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=ssciwr_vstt)

Visuomotor Serial Targeting Task (VSTT)

VSTT is an open source Python GUI tool for designing,
running and analyzing motor skill acquisition experiments.

See [vstt.readthedocs.io](https://vstt.readthedocs.io/) for more information.

![screenshot](https://raw.githubusercontent.com/ssciwr/vstt/main/docs/quickstart/images/gui.png)

![screenshot](https://raw.githubusercontent.com/ssciwr/vstt/main/docs/quickstart/images/results.png)
